NotPartOfTest
Invalid 2000-01-01 Invalid
Invalid 2000-01-01 Invalid 00:00:00
Invalid 2000-01-01 Invalid
Invalid 2000-01-01 Invalid Invalid 00:00:00 Invalid Invalid Invalid
Invalid
2000-01-01
Invalid
Invalid
2000-01-01
Invalid
Invalid 2000-01-01
23:59:59
Invalid
Invalid 2000-01-01
23:59:59
Invalid
NotPartOfTest
Valid NotADate Valid
Invalid 2000-01-01 00:00:00+00:00 Invalid
Invalid 2000-01-0100:00:00+00:00 Invalid
Invalid 2000-01-01 1999-12-31 Invalid
Invalid 00:00:00 2099-12-31 23:59:59 2000-01-01 Invalid
Invalid 2000-01-01 00:00:00 00:00:00+00:00 Invalid
NotPartOfTest
Invalid Invalid
Valid
Valid
NotPartOfTest
Invalid Invalid
Valid
Valid
NotPartOfTest
Invalid Invalid Invalid
Valid
Invalid 2000-01-01 Invalid
NotPartOfTest
Invalid Invalid Invalid
Valid
Invalid 2000-01-01 Invalid
NotPartOfTest
Invalid Invalid Invalid
Valid
Invalid 2000-01-01 Invalid
NotPartOfTest
Invalid Invalid Invalid
Valid
Invalid 2000-01-01 Invalid
NotPartOfTest
Invalid Invalid Invalid
Valid
Invalid 2000-01-01 Invalid
NotPartOfTest
Invalid 2000-01-01 Invalid Invalid 2000-01-01 Invalid Invalid 2000-01-01 Invalid Invalid 2000-01-01 Invalid Invalid 2000-01-01 Invalid